@@ -12,12 +12,13 @@
 
 namespace KWSDL {
 
+// clazy:excludeall=ctor-missing-parent-argument
 class Compiler : public QObject
 {
     Q_OBJECT
 
 public:
-    Compiler();
+    Compiler(); // created on stack
 
 public slots:
     void run();
