@@ -1,28 +1,22 @@
 /****************************************************************************
 **
-** This file is part of the KD Soap library.
+** This file is part of the KD Soap project.
 **
-** SPDX-FileCopyrightText: 2010-2020 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+** SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 **
-** SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
-**
-** Licensees holding valid commercial KD Soap licenses may use this file in
-** accordance with the KD Soap Commercial License Agreement provided with
-** the Software.
-**
-** Contact info@kdab.com if any conditions of this licensing are not clear to you.
+** SPDX-License-Identifier: MIT
 **
 ****************************************************************************/
 #ifndef KDSOAPPENDINGCALL_P_H
 #define KDSOAPPENDINGCALL_P_H
 
-#include <QSharedData>
-#include <QBuffer>
-#include <QXmlStreamReader>
-#include "KDSoapMessage.h"
-#include <QPointer>
 #include "KDSoapClientInterface.h"
+#include "KDSoapMessage.h"
+#include <QBuffer>
 #include <QNetworkReply>
+#include <QPointer>
+#include <QSharedData>
+#include <QXmlStreamReader>
 
 class KDSoapValue;
 
@@ -32,7 +26,10 @@ class KDSoapPendingCall::Private : public QSharedData
 {
 public:
     Private(QNetworkReply *r, QBuffer *b)
-        : reply(r), buffer(b), soapVersion(KDSoap::SOAP1_1), parsed(false)
+        : reply(r)
+        , buffer(b)
+        , soapVersion(KDSoap::SOAP1_1)
+        , parsed(false)
     {
     }
     ~Private();
